@@ -19,7 +19,7 @@ ExerciseWindow::ExerciseWindow(QWidget *parent) :
 
     vLayout = new QVBoxLayout;
 
-    label = new QLabel();
+    label = new QLabel("");
     label->setAlignment(Qt::AlignCenter);
 
     btnShake = new QPushButton("Done");
@@ -87,6 +87,11 @@ void ExerciseWindow::sendClosed()
 
 void ExerciseWindow::loadExercise(QList<QString> name)
 {
+    bool firstTime = false;
+    if(exercises.count() == 0)
+        firstTime = true;
+
+    exercises = name;
     QDBusConnection::sessionBus().send(lock);
     QList <QString> tmp;
     QList<QString> settings = xml->loadSettings();
@@ -116,21 +121,74 @@ void ExerciseWindow::loadExercise(QList<QString> name)
     if(settings.takeFirst() == "1")
         soundActive = true;
 
-    currentExercise = name.first();
+    if(exercises.count() == 1)
+    {
+        currentExercise = exercises.first();
+
+        tmp = xml->openEx(currentExercise);
+        tmp.removeFirst();
+        currentGroup = tmp.takeFirst();
+
+        set = SET; reps = REPS; min = MIN; sec = SEC;
+        strSet.setNum(SET); strReps.setNum(REPS); strMin.setNum(MIN);  strSec.setNum(SEC);
+        label->setText(currentExercise + "\n Shake when done " + strReps + " reps");
+        btnShake->setEnabled(true);
+        myThread->start(QThread::NormalPriority);
+    }
+
+    if(firstTime == true)
+    {
+        ed = new ExerciseDialog(this);
+        connect(ed,SIGNAL(exerciseName(QString)),this, SLOT(setCurrentExercise(QString)));
+        connect(ed,SIGNAL(destroyDialog()),this,SLOT(sendDestroyDialog()));
+        ed->load(exercises);
+        ed->show();
+    }
+
+
+}
+
+void ExerciseWindow::sendDestroyDialog()
+{
+    ed->~ExerciseDialog();
+}
+
+void ExerciseWindow::openED()
+{
+    if(exercises.count() > 1)
+    {
+        ed = new ExerciseDialog(this);
+        connect(ed,SIGNAL(exerciseName(QString)),this, SLOT(setCurrentExercise(QString)));
+        connect(ed,SIGNAL(destroyDialog()),this,SLOT(sendDestroyDialog()));
+        ed->load(exercises);
+        ed->show();
+    }
+}
+
+void ExerciseWindow::setCurrentExercise(QString name)
+{
+    QList <QString> tmp;
+    currentExercise = name;
+    QDBusMessage reply;
+
     tmp = xml->openEx(currentExercise);
     tmp.removeFirst();
     currentGroup = tmp.takeFirst();
 
+
     set = SET; reps = REPS; min = MIN; sec = SEC;
     strSet.setNum(SET); strReps.setNum(REPS); strMin.setNum(MIN);  strSec.setNum(SEC);
     label->setText(currentExercise + "\n Shake when done " + strReps + " reps");
+
     btnShake->setEnabled(true);
     myThread->start(QThread::NormalPriority);
+
+
+    reply = interface->call(MCE_TKLOCK_MODE_CHANGE_REQ, "locked");
 }
 
 void ExerciseWindow::changeEvent(QEvent *event)
 {
-    //qDebug() << label->text();
     this->update();
 }
 
@@ -166,6 +224,7 @@ void ExerciseWindow::showNewExercise()
 void ExerciseWindow::showNewProgram()
 {
     npw = new NewProgramWindow(this);
+    npw->load();
     npw->show();
 }
 
@@ -278,6 +337,7 @@ void ExerciseWindow::checkProximity(QString data)
 void ExerciseWindow::checkAcc(QString x)
 {
 
+
     if(x.toInt() > 2200 || x.toInt() < -2200)
     {
         if(proximity == false)
@@ -319,22 +379,32 @@ void ExerciseWindow::shaked()
             //QDBusConnection::sessionBus().send(resume);
 
         }
-        wd = new WeightDialog(this);
-        wd->load(currentExercise, currentGroup, currentReps);
-        wd->show();
-        if(!exercises.isEmpty())
+
+        if(exercises.count() > 1)
         {
-            exercises.removeFirst();
+            exercises.removeOne(currentExercise);
             loadExercise(exercises);
+
+            wd = new WeightDialog(this);
+            connect(wd,SIGNAL(next()),this,SLOT(openED()));
+            wd->load(currentExercise, currentGroup, currentReps);
+            wd->show();
             return;
         }
         else
         {
             label->setText("Exercise(s) completed!");
             btnShake->setEnabled(false);
+
+            wd = new WeightDialog(this);
+            wd->load(currentExercise, currentGroup, currentReps);
+            wd->show();
             return;
         }
 
+        wd = new WeightDialog(this);
+        wd->load(currentExercise, currentGroup, currentReps);
+        wd->show();
     }
 
     //Start wait and count down
