@@ -13,6 +13,7 @@
 #include "weightdialog.h"
 #include "newingredientwindow.h"
 #include "historywindow.h"
+#include "exercisedialog.h"
 
 class ExerciseWindow : public QMainWindow
 {
@@ -27,8 +28,12 @@ signals:
 
 public slots:
     void sendClosed();
+    void setCurrentExercise(QString name);
+    void sendDestroyDialog();
+    void openED();
 
 private:
+    ExerciseDialog *ed;
     SettingsWindow *sw;
     NewExerciseWindow *nw;
     NewIngredientWindow *niw;
