@@ -15,7 +15,7 @@ StartWindow::StartWindow(QWidget *parent) :
 
     QVBoxLayout *vLayout = new QVBoxLayout;
     QHBoxLayout *hLabelLayout = new QHBoxLayout;
-    lblWeight = new QLabel("Weight-lift/week \n 1050kg \n 3 times/week");
+    lblWeight = new QLabel("Weight-lift/week \n 1000kg \n 3 times/week");
     lblCardio = new QLabel("Cardio/week \n 325km \n 5 times/week");
 
     lblWeight->setAlignment(Qt::AlignCenter);
@@ -30,7 +30,9 @@ StartWindow::StartWindow(QWidget *parent) :
 
     btnCardio = new QPushButton(QIcon(":/res/images/cardio.png"),"",this);
     connect(btnCardio,SIGNAL(clicked()),this,SLOT(showCardio()));
+
     btnProgram = new QPushButton(QIcon(":/res/images/program.png"),"",this);
+    connect(btnProgram,SIGNAL(clicked()),this,SLOT(showProgram()));
 
     btnFood = new QPushButton(QIcon(":/res/images/food.png"),"",this);
     connect(btnFood,SIGNAL(clicked()),this, SLOT(showFood()));
@@ -238,6 +240,15 @@ void StartWindow::showCardio()
     lw->show();
 }
 
+void StartWindow::showProgram()
+{
+    lw = new ListWindow(this);
+    connect(lw,SIGNAL(closed()),this,SLOT(restorePortrait()));
+    connect(lw,SIGNAL(landscape()),this, SLOT(setLandscape()));
+    lw->loadExercises("Program");
+    lw->show();
+}
+
 void StartWindow::showSettings()
 {
     sw = new SettingsWindow(this);
@@ -258,6 +269,7 @@ void StartWindow::showNewExercise()
 void StartWindow::showNewProgram()
 {
     npw = new NewProgramWindow(this);
+    npw->load();
     npw->show();
 }
 
